// Code generated by tygo. DO NOT EDIT.
import * as MautrixID from "./id/index.ts"
import * as MautrixBridgeV2 from "./bridgev2/index.ts"
import * as MautrixEvent from "./event/index.ts"
import * as MautrixBridgeV2Commands from "./bridgev2/commands/index.ts"
import * as MautrixBridgeV2NetworkID from "./bridgev2/networkid/index.ts"
import * as MautrixBridgeStatus from "./bridge/status/index.ts"
import * as BeeperSDKBridgesTypes from "../../../github.com/beeper/beeper-client-sdk/pkg/bridges/types/index.ts"
//////////
// source: client.go
/*
Package mautrix implements the Matrix Client-Server API.

Specification can be found at https://spec.matrix.org/v1.2/client-server-api/
*/

export type CryptoHelper = any;
export type VerificationHelper = any;
/**
 * Client represents a Matrix client.
 */
export interface Client {
  HomeserverURL?: any /* url.URL */; // The base homeserver URL
  UserID: MautrixID.UserID; // The user ID of the client. Used for forming HTTP paths which use the client's user ID.
  DeviceID: MautrixID.DeviceID; // The device ID of the client.
  AccessToken: string; // The access_token for the client.
  UserAgent: string; // The value for the User-Agent header
  Client?: any /* http.Client */; // The underlying HTTP client which will be used to make HTTP requests.
  Syncer: Syncer; // The thing which can process /sync responses
  Store: SyncStore; // The thing which can store tokens/ids
  StateStore: StateStore;
  Crypto: CryptoHelper;
  Verification: VerificationHelper;
  SpecVersions?: RespVersions;
  ExternalClient?: any /* http.Client */; // The HTTP client used for external (not matrix) media HTTP requests.
  Log: any /* zerolog.Logger */;
  RequestHook: any;
  ResponseHook: any;
  UpdateRequestOnRetry: any;
  SyncPresence: any /* event.Presence */;
  SyncTraceLog: boolean;
  StreamSyncMinAge: any /* time.Duration */;
  /**
   * Number of times that mautrix will retry any HTTP request
   * if the request fails entirely or returns a HTTP gateway error (502-504)
   */
  DefaultHTTPRetries: number /* int */;
  /**
   * Amount of time to wait between HTTP retries, defaults to 4 seconds
   */
  DefaultHTTPBackoff: any /* time.Duration */;
  /**
   * Set to true to disable automatically sleeping on 429 errors.
   */
  IgnoreRateLimit: boolean;
  /**
   * Should the ?user_id= query parameter be set in requests?
   * See https://spec.matrix.org/v1.6/application-service-api/#identity-assertion
   */
  SetAppServiceUserID: boolean;
  /**
   * Should the org.matrix.msc3202.device_id query parameter be set in requests?
   * See https://github.com/matrix-org/matrix-spec-proposals/pull/3202
   */
  SetAppServiceDeviceID: boolean;
}
export interface ClientWellKnown {
  'm.homeserver': HomeserverInfo;
  'm.identity_server': IdentityServerInfo;
}
export interface HomeserverInfo {
  base_url: string;
}
export interface IdentityServerInfo {
  base_url: string;
}
export const LogBodyContextKey: contextKey = 0;
export const LogRequestIDContextKey: contextKey = 1;
export const MaxAttemptsContextKey: contextKey = 2;
export type ClientResponseHandler = any;
export interface FullRequest {
  Method: string;
  URL: string;
  Headers: any /* http.Header */;
  RequestJSON: any;
  RequestBytes: string;
  RequestBody: any /* io.Reader */;
  RequestLength: number /* int64 */;
  ResponseJSON: any;
  MaxAttempts: number /* int */;
  BackoffDuration: any /* time.Duration */;
  SensitiveContent: boolean;
  Handler: ClientResponseHandler;
  DontReadResponse: boolean;
  Logger?: any /* zerolog.Logger */;
  Client?: any /* http.Client */;
}
export interface ReqSync {
  Timeout: number /* int */;
  Since: string;
  FilterID: string;
  FullState: boolean;
  SetPresence: any /* event.Presence */;
  StreamResponse: boolean;
  UseStateAfter: boolean;
  BeeperStreaming: boolean;
  Client?: any /* http.Client */;
}
export interface ReqCreateMXC {
  BeeperUniqueID: string;
  BeeperRoomID: MautrixID.RoomID;
}
export interface ReqUploadMedia {
  ContentBytes: string;
  Content: any /* io.Reader */;
  ContentLength: number /* int64 */;
  ContentType: string;
  FileName: string;
  DoneCallback: any;
  /**
   * MXC specifies an existing MXC URI which doesn't have content yet to upload into.
   * See https://spec.matrix.org/unstable/client-server-api/#put_matrixmediav3uploadservernamemediaid
   */
  MXC: any /* id.ContentURI */;
  /**
   * UnstableUploadURL specifies the URL to upload the content to. MXC must also be set.
   * see https://github.com/matrix-org/matrix-spec-proposals/pull/3870 for more info
   */
  UnstableUploadURL: string;
}
export type UIACallback = any;

//////////
// source: error.go

/**
 * HTTPError An HTTP Error response, which may wrap an underlying native Go Error.
 */
export interface HTTPError {
  Request?: any /* http.Request */;
  Response?: any /* http.Response */;
  ResponseBody: string;
  WrappedError: error;
  RespError?: RespError;
  Message: string;
}
/**
 * RespError is the standard JSON error response from Homeservers. It also implements the Golang "error" interface.
 * See https://spec.matrix.org/v1.2/client-server-api/#api-standards
 */
export interface RespError {
  ErrCode: string;
  Err: string;
  ExtraData: { [key: string]: any};
  StatusCode: number /* int */;
}

//////////
// source: filter.go

export type EventFormat = string;
export const EventFormatClient: EventFormat = "client";
export const EventFormatFederation: EventFormat = "federation";
/**
 * Filter is used by clients to specify how the server should filter responses to e.g. sync requests
 * Specified by: https://spec.matrix.org/v1.2/client-server-api/#filtering
 */
export interface Filter {
  account_data?: FilterPart;
  event_fields?: string[];
  event_format?: EventFormat;
  presence?: FilterPart;
  room?: RoomFilter;
  'com.beeper.to_device'?: FilterPart;
}
/**
 * RoomFilter is used to define filtering rules for room events
 */
export interface RoomFilter {
  account_data?: FilterPart;
  ephemeral?: FilterPart;
  include_leave?: boolean;
  not_rooms?: MautrixID.RoomID[];
  rooms?: MautrixID.RoomID[];
  state?: FilterPart;
  timeline?: FilterPart;
}
/**
 * FilterPart is used to define filtering rules for specific categories of events
 */
export interface FilterPart {
  not_rooms?: MautrixID.RoomID[];
  rooms?: MautrixID.RoomID[];
  limit?: number /* int */;
  not_senders?: MautrixID.UserID[];
  not_types?: MautrixEvent.Type[];
  senders?: MautrixID.UserID[];
  types?: MautrixEvent.Type[];
  contains_url?: boolean;
  lazy_load_members?: boolean;
  include_redundant_members?: boolean;
  unread_thread_notifications?: boolean;
}

//////////
// source: requests.go

export type AuthType = string;
export const AuthTypePassword: AuthType = "m.login.password";
export const AuthTypeReCAPTCHA: AuthType = "m.login.recaptcha";
export const AuthTypeOAuth2: AuthType = "m.login.oauth2";
export const AuthTypeSSO: AuthType = "m.login.sso";
export const AuthTypeEmail: AuthType = "m.login.email.identity";
export const AuthTypeMSISDN: AuthType = "m.login.msisdn";
export const AuthTypeToken: AuthType = "m.login.token";
export const AuthTypeDummy: AuthType = "m.login.dummy";
export const AuthTypeAppservice: AuthType = "m.login.application_service";
export const AuthTypeSynapseJWT: AuthType = "org.matrix.login.jwt";
export const AuthTypeDevtureSharedSecret: AuthType = "com.devture.shared_secret_auth";
export type IdentifierType = string;
export const IdentifierTypeUser = "m.id.user";
export const IdentifierTypeThirdParty = "m.id.thirdparty";
export const IdentifierTypePhone = "m.id.phone";
export type Direction = number /* rune */;
export const DirectionForward: Direction = 0x0066 /* 'f' */;
export const DirectionBackward: Direction = 0x0062 /* 'b' */;
/**
 * ReqRegister is the JSON request for https://spec.matrix.org/v1.2/client-server-api/#post_matrixclientv3register
 */
export interface ReqRegister {
  username?: string;
  password?: string;
  device_id?: MautrixID.DeviceID;
  initial_device_display_name?: string;
  inhibit_login?: boolean;
  refresh_token?: boolean;
  auth?: any;
  /**
   * Type for registration, only used for appservice user registrations
   * https://spec.matrix.org/v1.2/application-service-api/#server-admin-style-permissions
   */
  type?: AuthType;
}
export interface BaseAuthData {
  type: AuthType;
  session?: string;
}
export interface UserIdentifier {
  type: IdentifierType;
  user?: string;
  medium?: string;
  address?: string;
  country?: string;
  phone?: string;
}
/**
 * ReqLogin is the JSON request for https://spec.matrix.org/v1.2/client-server-api/#post_matrixclientv3login
 */
export interface ReqLogin {
  type: AuthType;
  identifier: UserIdentifier;
  password?: string;
  token?: string;
  device_id?: MautrixID.DeviceID;
  initial_device_display_name?: string;
  refresh_token?: boolean;
}
export interface ReqPutDevice {
  display_name?: string;
}
export interface ReqUIAuthFallback {
  session: string;
  user: string;
}
export interface ReqUIAuthLogin {
  BaseAuthData: BaseAuthData;
  user?: string;
  password?: string;
  token?: string;
}
/**
 * ReqCreateRoom is the JSON request for https://spec.matrix.org/v1.2/client-server-api/#post_matrixclientv3createroom
 */
export interface ReqCreateRoom {
  visibility?: string;
  room_alias_name?: string;
  name?: string;
  topic?: string;
  invite?: MautrixID.UserID[];
  invite_3pid?: ReqInvite3PID[];
  creation_content?: { [key: string]: any};
  initial_state?: (MautrixEvent.Event | undefined)[];
  preset?: string;
  is_direct?: boolean;
  room_version?: string;
  power_level_content_override?: MautrixEvent.PowerLevelsEventContent;
  'fi.mau.room_id'?: MautrixID.RoomID;
  'com.beeper.initial_members'?: MautrixID.UserID[];
  'com.beeper.auto_join_invites'?: boolean;
  'com.beeper.local_room_id'?: MautrixID.RoomID;
  'com.beeper.bridge_name'?: string;
  'com.beeper.bridge_account_id'?: string;
}
/**
 * ReqRedact is the JSON request for https://spec.matrix.org/v1.2/client-server-api/#put_matrixclientv3roomsroomidredacteventidtxnid
 */
export interface ReqRedact {
  Reason: string;
  TxnID: string;
  Extra: { [key: string]: any};
}
export interface ReqRedactUser {
  reason: string;
}
export interface ReqMembers {
  at: string;
  membership?: any /* event.Membership */;
  not_membership?: any /* event.Membership */;
}
export interface ReqJoinRoom {
  reason?: string;
  third_party_signed?: any;
}
export interface ReqKnockRoom {
  reason?: string;
}
export interface ReqMutualRooms {
}
/**
 * ReqInvite3PID is the JSON request for https://spec.matrix.org/v1.2/client-server-api/#post_matrixclientv3roomsroomidinvite-1
 * It is also a JSON object used in https://spec.matrix.org/v1.2/client-server-api/#post_matrixclientv3createroom
 */
export interface ReqInvite3PID {
  id_server: string;
  medium: string;
  address: string;
}
export interface ReqLeave {
  reason?: string;
}
/**
 * ReqInviteUser is the JSON request for https://spec.matrix.org/v1.2/client-server-api/#post_matrixclientv3roomsroomidinvite
 */
export interface ReqInviteUser {
  reason?: string;
  user_id: MautrixID.UserID;
}
/**
 * ReqKickUser is the JSON request for https://spec.matrix.org/v1.2/client-server-api/#post_matrixclientv3roomsroomidkick
 */
export interface ReqKickUser {
  reason?: string;
  user_id: MautrixID.UserID;
}
/**
 * ReqBanUser is the JSON request for https://spec.matrix.org/v1.2/client-server-api/#post_matrixclientv3roomsroomidban
 */
export interface ReqBanUser {
  reason?: string;
  user_id: MautrixID.UserID;
}
/**
 * ReqUnbanUser is the JSON request for https://spec.matrix.org/v1.2/client-server-api/#post_matrixclientv3roomsroomidunban
 */
export interface ReqUnbanUser {
  reason?: string;
  user_id: MautrixID.UserID;
}
/**
 * ReqTyping is the JSON request for https://spec.matrix.org/v1.2/client-server-api/#put_matrixclientv3roomsroomidtypinguserid
 */
export interface ReqTyping {
  typing: boolean;
  timeout?: number /* int64 */;
}
export interface ReqPresence {
  presence: any /* event.Presence */;
  status_msg?: string;
}
export interface ReqAliasCreate {
  room_id: MautrixID.RoomID;
}
export interface OneTimeKey {
  key: any /* id.Curve25519 */;
  fallback?: boolean;
  signatures?: any /* signatures.Signatures */;
  unsigned?: { [key: string]: any};
}
export interface ReqUploadKeys {
  device_keys?: DeviceKeys;
  one_time_keys?: { [key: any /* id.KeyID */]: OneTimeKey};
}
export interface ReqKeysSignatures {
  user_id: MautrixID.UserID;
  device_id?: MautrixID.DeviceID;
  algorithms?: any /* id.Algorithm */[];
  usage?: any /* id.CrossSigningUsage */[];
  keys: { [key: any /* id.KeyID */]: string};
  signatures: any /* signatures.Signatures */;
}
export type ReqUploadSignatures = { [key: MautrixID.UserID]: { [key: string]: ReqKeysSignatures}};
export interface DeviceKeys {
  user_id: MautrixID.UserID;
  device_id: MautrixID.DeviceID;
  algorithms: any /* id.Algorithm */[];
  keys: KeyMap;
  signatures: any /* signatures.Signatures */;
  unsigned?: { [key: string]: any};
}
export interface CrossSigningKeys {
  user_id: MautrixID.UserID;
  usage: any /* id.CrossSigningUsage */[];
  keys: { [key: any /* id.KeyID */]: any /* id.Ed25519 */};
  signatures?: any /* signatures.Signatures */;
}
export interface UploadCrossSigningKeysReq {
  master_key: CrossSigningKeys;
  self_signing_key: CrossSigningKeys;
  user_signing_key: CrossSigningKeys;
  auth?: any;
}
export type KeyMap = { [key: any /* id.DeviceKeyID */]: string};
export interface ReqQueryKeys {
  device_keys: DeviceKeysRequest;
  timeout?: number /* int64 */;
}
export type DeviceKeysRequest = { [key: MautrixID.UserID]: DeviceIDList};
export type DeviceIDList = MautrixID.DeviceID[];
export interface ReqClaimKeys {
  one_time_keys: OneTimeKeysRequest;
  timeout?: number /* int64 */;
}
export type OneTimeKeysRequest = { [key: MautrixID.UserID]: { [key: MautrixID.DeviceID]: any /* id.KeyAlgorithm */}};
export interface ReqSendToDevice {
  messages: { [key: MautrixID.UserID]: { [key: MautrixID.DeviceID]: any /* event.Content */ | undefined}};
}
export interface ReqSendEvent {
  Timestamp: number /* int64 */;
  TransactionID: string;
  UnstableDelay: any /* time.Duration */;
  DontEncrypt: boolean;
  MeowEventID: MautrixID.EventID;
}
export interface ReqUpdateDelayedEvent {
  action: string; // TODO use enum
}
/**
 * ReqDeviceInfo is the JSON request for https://spec.matrix.org/v1.2/client-server-api/#put_matrixclientv3devicesdeviceid
 */
export interface ReqDeviceInfo {
  display_name?: string;
}
/**
 * ReqDeleteDevice is the JSON request for https://spec.matrix.org/v1.2/client-server-api/#delete_matrixclientv3devicesdeviceid
 */
export interface ReqDeleteDevice {
  auth?: any;
}
/**
 * ReqDeleteDevices is the JSON request for https://spec.matrix.org/v1.2/client-server-api/#post_matrixclientv3delete_devices
 */
export interface ReqDeleteDevices {
  devices: MautrixID.DeviceID[];
  auth?: any;
}
export interface ReqPutPushRule {
  actions: any /* pushrules.PushActionType */[];
  conditions: any /* pushrules.PushCondition */[];
  pattern: string;
}
/**
 * Deprecated: MSC2716 was abandoned
 */
export interface ReqBatchSend {
  state_events_at_start: (MautrixEvent.Event | undefined)[];
  events: (MautrixEvent.Event | undefined)[];
}
export interface ReqBeeperBatchSend {
  /**
   * ForwardIfNoMessages should be set to true if the batch should be forward
   * backfilled if there are no messages currently in the room.
   */
  forward_if_no_messages: boolean;
  forward: boolean;
  send_notification: boolean;
  mark_read_by?: MautrixID.UserID;
  events: (MautrixEvent.Event | undefined)[];
}
export interface ReqSetReadMarkers {
  'm.read'?: MautrixID.EventID;
  'm.read.private'?: MautrixID.EventID;
  'm.fully_read'?: MautrixID.EventID;
  'com.beeper.read.extra'?: any;
  'com.beeper.read.private.extra'?: any;
  'com.beeper.fully_read.extra'?: any;
}
export interface BeeperInboxDone {
  at_delta: number /* int64 */;
  at_order: number /* int64 */;
}
export interface ReqSetBeeperInboxState {
  marked_unread?: boolean;
  done?: BeeperInboxDone;
  read_markers?: ReqSetReadMarkers;
}
export interface ReqSendReceipt {
  thread_id?: string;
}
export interface ReqPublicRooms {
  IncludeAllNetworks: boolean;
  Limit: number /* int */;
  Since: string;
  ThirdPartyInstanceID: string;
}
/**
 * ReqHierarchy contains the parameters for https://spec.matrix.org/v1.4/client-server-api/#get_matrixclientv1roomsroomidhierarchy
 * As it's a GET method, there is no JSON body, so this is only query parameters.
 */
export interface ReqHierarchy {
  /**
   * A pagination token from a previous Hierarchy call.
   * If specified, max_depth and suggested_only cannot be changed from the first request.
   */
  From: string;
  /**
   * Limit for the maximum number of rooms to include per response.
   * The server will apply a default value if a limit isn't provided.
   */
  Limit: number /* int */;
  /**
   * Limit for how far to go into the space. When reached, no further child rooms will be returned.
   * The server will apply a default value if a max depth isn't provided.
   */
  MaxDepth?: number /* int */;
  /**
   * Flag to indicate whether the server should only consider suggested rooms.
   * Suggested rooms are annotated in their m.space.child event contents.
   */
  SuggestedOnly: boolean;
}
export interface ReqAppservicePing {
  transaction_id?: string;
}
export interface ReqBeeperMergeRoom {
  create: ReqCreateRoom;
  key: string;
  rooms: MautrixID.RoomID[];
  user_id: MautrixID.UserID;
}
export interface BeeperSplitRoomPart {
  user_id: MautrixID.UserID;
  values: string[];
  create: ReqCreateRoom;
}
export interface ReqBeeperSplitRoom {
  key: string;
  parts: BeeperSplitRoomPart[];
}
export interface ReqRoomKeysVersionCreate<A extends any> {
  algorithm: any /* id.KeyBackupAlgorithm */;
  auth_data: A;
}
export interface ReqRoomKeysVersionUpdate<A extends any> {
  algorithm: any /* id.KeyBackupAlgorithm */;
  auth_data: A;
  version?: any /* id.KeyBackupVersion */;
}
export interface ReqKeyBackup {
  rooms: { [key: MautrixID.RoomID]: ReqRoomKeyBackup};
}
export interface ReqRoomKeyBackup {
  sessions: { [key: any /* id.SessionID */]: ReqKeyBackupData};
}
export interface ReqKeyBackupData {
  first_message_index: number /* int */;
  forwarded_count: number /* int */;
  is_verified: boolean;
  session_data: any /* json.RawMessage */;
}
export interface ReqReport {
  reason?: string;
  score?: number /* int */;
}

//////////
// source: responses.go

/**
 * RespWhoami is the JSON response for https://spec.matrix.org/v1.2/client-server-api/#get_matrixclientv3accountwhoami
 */
export interface RespWhoami {
  user_id: MautrixID.UserID;
  device_id: MautrixID.DeviceID;
}
/**
 * RespCreateFilter is the JSON response for https://spec.matrix.org/v1.2/client-server-api/#post_matrixclientv3useruseridfilter
 */
export interface RespCreateFilter {
  filter_id: string;
}
/**
 * RespJoinRoom is the JSON response for https://spec.matrix.org/v1.2/client-server-api/#post_matrixclientv3roomsroomidjoin
 */
export interface RespJoinRoom {
  room_id: MautrixID.RoomID;
}
/**
 * RespKnockRoom is the JSON response for https://spec.matrix.org/v1.13/client-server-api/#post_matrixclientv3knockroomidoralias
 */
export interface RespKnockRoom {
  room_id: MautrixID.RoomID;
}
/**
 * RespLeaveRoom is the JSON response for https://spec.matrix.org/v1.2/client-server-api/#post_matrixclientv3roomsroomidleave
 */
export interface RespLeaveRoom {
}
/**
 * RespForgetRoom is the JSON response for https://spec.matrix.org/v1.2/client-server-api/#post_matrixclientv3roomsroomidforget
 */
export interface RespForgetRoom {
}
/**
 * RespInviteUser is the JSON response for https://spec.matrix.org/v1.2/client-server-api/#post_matrixclientv3roomsroomidinvite
 */
export interface RespInviteUser {
}
/**
 * RespKickUser is the JSON response for https://spec.matrix.org/v1.2/client-server-api/#post_matrixclientv3roomsroomidkick
 */
export interface RespKickUser {
}
/**
 * RespBanUser is the JSON response for https://spec.matrix.org/v1.2/client-server-api/#post_matrixclientv3roomsroomidban
 */
export interface RespBanUser {
}
/**
 * RespUnbanUser is the JSON response for https://spec.matrix.org/v1.2/client-server-api/#post_matrixclientv3roomsroomidunban
 */
export interface RespUnbanUser {
}
/**
 * RespTyping is the JSON response for https://spec.matrix.org/v1.2/client-server-api/#put_matrixclientv3roomsroomidtypinguserid
 */
export interface RespTyping {
}
/**
 * RespPresence is the JSON response for https://spec.matrix.org/v1.2/client-server-api/#get_matrixclientv3presenceuseridstatus
 */
export interface RespPresence {
  presence: any /* event.Presence */;
  last_active_ago: number /* int */;
  status_msg: string;
  currently_active: boolean;
}
/**
 * RespJoinedRooms is the JSON response for https://spec.matrix.org/v1.2/client-server-api/#get_matrixclientv3joined_rooms
 */
export interface RespJoinedRooms {
  joined_rooms: MautrixID.RoomID[];
}
/**
 * RespJoinedMembers is the JSON response for https://spec.matrix.org/v1.2/client-server-api/#get_matrixclientv3roomsroomidjoined_members
 */
export interface RespJoinedMembers {
  joined: { [key: MautrixID.UserID]: JoinedMember};
}
export interface JoinedMember {
  display_name?: string;
  avatar_url?: string;
}
/**
 * RespMessages is the JSON response for https://spec.matrix.org/v1.2/client-server-api/#get_matrixclientv3roomsroomidmessages
 */
export interface RespMessages {
  start: string;
  chunk: (MautrixEvent.Event | undefined)[];
  state: (MautrixEvent.Event | undefined)[];
  end?: string;
}
/**
 * RespContext is the JSON response for https://spec.matrix.org/v1.2/client-server-api/#get_matrixclientv3roomsroomidcontexteventid
 */
export interface RespContext {
  end: string;
  event?: MautrixEvent.Event;
  events_after: (MautrixEvent.Event | undefined)[];
  events_before: (MautrixEvent.Event | undefined)[];
  start: string;
  state: (MautrixEvent.Event | undefined)[];
}
/**
 * RespSendEvent is the JSON response for https://spec.matrix.org/v1.2/client-server-api/#put_matrixclientv3roomsroomidsendeventtypetxnid
 */
export interface RespSendEvent {
  event_id: MautrixID.EventID;
  delay_id?: string;
}
export interface RespUpdateDelayedEvent {
}
export interface RespRedactUserEvents {
  is_more_events: boolean;
  redacted_events: {
    total: number /* int */;
    soft_failed: number /* int */;
  };
}
/**
 * RespMediaConfig is the JSON response for https://spec.matrix.org/v1.4/client-server-api/#get_matrixmediav3config
 */
export interface RespMediaConfig {
  'm.upload.size'?: number /* int64 */;
}
/**
 * RespMediaUpload is the JSON response for https://spec.matrix.org/v1.2/client-server-api/#post_matrixmediav3upload
 */
export interface RespMediaUpload {
  content_uri: any /* id.ContentURI */;
}
/**
 * RespCreateMXC is the JSON response for https://spec.matrix.org/v1.7/client-server-api/#post_matrixmediav1create
 */
export interface RespCreateMXC {
  content_uri: any /* id.ContentURI */;
  unused_expires_at?: any /* jsontime.UnixMilli */;
  'com.beeper.msc3870.upload_url'?: string;
  /**
   * Beeper extensions for uploading unique media only once
   */
  'com.beeper.unique_id'?: string;
  'com.beeper.completed_at'?: any /* jsontime.UnixMilli */;
}
/**
 * RespPreviewURL is the JSON response for https://spec.matrix.org/v1.2/client-server-api/#get_matrixmediav3preview_url
 */
export type RespPreviewURL = any /* event.LinkPreview */;
/**
 * RespUserInteractive is the JSON response for https://spec.matrix.org/v1.2/client-server-api/#user-interactive-authentication-api
 */
export interface RespUserInteractive {
  flows?: UIAFlow[];
  params?: { [key: AuthType]: any};
  session?: string;
  completed?: string[];
  errcode?: string;
  error?: string;
}
export interface UIAFlow {
  stages?: AuthType[];
}
/**
 * RespUserDisplayName is the JSON response for https://spec.matrix.org/v1.2/client-server-api/#get_matrixclientv3profileuseriddisplayname
 */
export interface RespUserDisplayName {
  displayname: string;
}
export interface RespUserProfile {
  displayname?: string;
  avatar_url?: any /* id.ContentURI */;
}
export interface RespMutualRooms {
  joined: MautrixID.RoomID[];
  next_batch?: string;
}
export interface RespRoomSummary {
  PublicRoomInfo: PublicRoomInfo;
  membership?: any /* event.Membership */;
  room_version?: any /* event.RoomVersion */;
  encryption?: any /* id.Algorithm */;
  allowed_room_ids?: MautrixID.RoomID[];
  'im.nheko.summary.room_version'?: any /* event.RoomVersion */;
  'im.nheko.summary.version'?: any /* event.RoomVersion */;
  'im.nheko.summary.encryption'?: any /* id.Algorithm */;
}
/**
 * RespRegisterAvailable is the JSON response for https://spec.matrix.org/v1.4/client-server-api/#get_matrixclientv3registeravailable
 */
export interface RespRegisterAvailable {
  available: boolean;
}
/**
 * RespRegister is the JSON response for https://spec.matrix.org/v1.2/client-server-api/#post_matrixclientv3register
 */
export interface RespRegister {
  access_token?: string;
  device_id?: MautrixID.DeviceID;
  user_id: MautrixID.UserID;
  refresh_token?: string;
  expires_in_ms?: number /* int64 */;
  /**
   * Deprecated: homeserver should be parsed from the user ID
   */
  home_server?: string;
}
export interface LoginFlow {
  type: AuthType;
}
/**
 * RespLoginFlows is the JSON response for https://spec.matrix.org/v1.2/client-server-api/#get_matrixclientv3login
 */
export interface RespLoginFlows {
  flows: LoginFlow[];
}
/**
 * RespLogin is the JSON response for https://spec.matrix.org/v1.2/client-server-api/#post_matrixclientv3login
 */
export interface RespLogin {
  access_token: string;
  device_id: MautrixID.DeviceID;
  user_id: MautrixID.UserID;
  well_known?: ClientWellKnown;
  refresh_token?: string;
  expires_in_ms?: number /* int64 */;
}
/**
 * RespLogout is the JSON response for https://spec.matrix.org/v1.2/client-server-api/#post_matrixclientv3logout
 */
export interface RespLogout {
}
/**
 * RespCreateRoom is the JSON response for https://spec.matrix.org/v1.2/client-server-api/#post_matrixclientv3createroom
 */
export interface RespCreateRoom {
  room_id: MautrixID.RoomID;
}
export interface RespMembers {
  chunk: (MautrixEvent.Event | undefined)[];
}
export interface LazyLoadSummary {
  'm.heroes'?: MautrixID.UserID[];
  'm.joined_member_count'?: number /* int */;
  'm.invited_member_count'?: number /* int */;
}
export interface SyncEventsList {
  events?: (MautrixEvent.Event | undefined)[];
}
export interface SyncTimeline {
  SyncEventsList: SyncEventsList;
  limited?: boolean;
  prev_batch?: string;
}
/**
 * RespSync is the JSON response for https://spec.matrix.org/v1.2/client-server-api/#get_matrixclientv3sync
 */
export interface RespSync {
  next_batch: string;
  account_data: SyncEventsList;
  presence: SyncEventsList;
  to_device: SyncEventsList;
  device_lists: DeviceLists;
  device_one_time_keys_count: OTKCount;
  device_unused_fallback_key_types: any /* id.KeyAlgorithm */[];
  rooms: RespSyncRooms;
}
export interface RespSyncRooms {
  leave?: { [key: MautrixID.RoomID]: SyncLeftRoom | undefined};
  join?: { [key: MautrixID.RoomID]: SyncJoinedRoom | undefined};
  invite?: { [key: MautrixID.RoomID]: SyncInvitedRoom | undefined};
  knock?: { [key: MautrixID.RoomID]: SyncKnockedRoom | undefined};
}
export interface DeviceLists {
  changed?: MautrixID.UserID[];
  left?: MautrixID.UserID[];
}
export interface OTKCount {
  curve25519?: number /* int */;
  signed_curve25519?: number /* int */;
}
export interface SyncLeftRoom {
  summary: LazyLoadSummary;
  state: SyncEventsList;
  timeline: SyncTimeline;
}
export interface BeeperInboxPreviewEvent {
  event_id: MautrixID.EventID;
  origin_server_ts: any /* jsontime.UnixMilli */;
  event?: MautrixEvent.Event;
}
export interface SyncJoinedRoom {
  summary: LazyLoadSummary;
  state: SyncEventsList;
  'org.matrix.msc4222.state_after'?: SyncEventsList;
  timeline: SyncTimeline;
  ephemeral: SyncEventsList;
  account_data: SyncEventsList;
  unread_notifications?: UnreadNotificationCounts;
  /**
   * https://github.com/matrix-org/matrix-spec-proposals/pull/2654
   */
  'org.matrix.msc2654.unread_count'?: number /* int */;
  /**
   * Beeper extension
   */
  'com.beeper.inbox.preview'?: BeeperInboxPreviewEvent;
}
export interface UnreadNotificationCounts {
  highlight_count: number /* int */;
  notification_count: number /* int */;
}
export interface SyncInvitedRoom {
  invite_state: SyncEventsList;
}
export interface SyncKnockedRoom {
  knock_state: SyncEventsList;
}
export interface RespTurnServer {
  username: string;
  password: string;
  ttl: number /* int */;
  uris: string[];
}
export interface RespAliasCreate {
}
export interface RespAliasDelete {
}
export interface RespAliasResolve {
  room_id: MautrixID.RoomID;
  servers: string[];
}
export interface RespAliasList {
  aliases: any /* id.RoomAlias */[];
}
export interface RespUploadKeys {
  one_time_key_counts: OTKCount;
}
export interface RespQueryKeys {
  failures?: { [key: string]: any};
  device_keys: { [key: MautrixID.UserID]: { [key: MautrixID.DeviceID]: DeviceKeys}};
  master_keys: { [key: MautrixID.UserID]: CrossSigningKeys};
  self_signing_keys: { [key: MautrixID.UserID]: CrossSigningKeys};
  user_signing_keys: { [key: MautrixID.UserID]: CrossSigningKeys};
}
export interface RespClaimKeys {
  failures?: { [key: string]: any};
  one_time_keys: { [key: MautrixID.UserID]: { [key: MautrixID.DeviceID]: { [key: any /* id.KeyID */]: OneTimeKey}}};
}
export interface RespUploadSignatures {
  failures?: { [key: string]: any};
}
export interface RespKeyChanges {
  changed: MautrixID.UserID[];
  left: MautrixID.UserID[];
}
export interface RespSendToDevice {
}
/**
 * RespDevicesInfo is the JSON response for https://spec.matrix.org/v1.2/client-server-api/#get_matrixclientv3devices
 */
export interface RespDevicesInfo {
  devices: RespDeviceInfo[];
}
/**
 * RespDeviceInfo is the JSON response for https://spec.matrix.org/v1.2/client-server-api/#get_matrixclientv3devicesdeviceid
 */
export interface RespDeviceInfo {
  device_id: MautrixID.DeviceID;
  display_name: string;
  last_seen_ip: string;
  last_seen_ts: number /* int64 */;
}
/**
 * Deprecated: MSC2716 was abandoned
 */
export interface RespBatchSend {
  state_event_ids: MautrixID.EventID[];
  event_ids: MautrixID.EventID[];
  insertion_event_id: MautrixID.EventID;
  batch_event_id: MautrixID.EventID;
  base_insertion_event_id: MautrixID.EventID;
  next_batch_id: any /* id.BatchID */;
}
export interface RespBeeperBatchSend {
  event_ids: MautrixID.EventID[];
}
/**
 * RespCapabilities is the JSON response for https://spec.matrix.org/v1.3/client-server-api/#get_matrixclientv3capabilities
 */
export interface RespCapabilities {
  'm.room_versions'?: CapRoomVersions;
  'm.change_password'?: CapBooleanTrue;
  'm.set_displayname'?: CapBooleanTrue;
  'm.set_avatar_url'?: CapBooleanTrue;
  'm.3pid_changes'?: CapBooleanTrue;
  'm.get_login_token'?: CapBooleanTrue;
}
export interface CapBoolean {
  enabled: boolean;
}
export type CapBooleanTrue = CapBoolean;
export type CapBooleanFalse = CapBoolean;
export type CapRoomVersionStability = string;
export const CapRoomVersionStable: CapRoomVersionStability = "stable";
export const CapRoomVersionUnstable: CapRoomVersionStability = "unstable";
export interface CapRoomVersions {
  default: string;
  available: { [key: string]: CapRoomVersionStability};
}
export interface RespPublicRooms {
  chunk: (PublicRoomInfo | undefined)[];
  next_batch?: string;
  prev_batch?: string;
  total_room_count_estimate: number /* int */;
}
export interface PublicRoomInfo {
  room_id: MautrixID.RoomID;
  avatar_url?: MautrixID.ContentURIString;
  canonical_alias?: any /* id.RoomAlias */;
  guest_can_join: boolean;
  join_rule?: any /* event.JoinRule */;
  name?: string;
  num_joined_members: number /* int */;
  room_type: any /* event.RoomType */;
  topic?: string;
  world_readable: boolean;
}
/**
 * RespHierarchy is the JSON response for https://spec.matrix.org/v1.4/client-server-api/#get_matrixclientv1roomsroomidhierarchy
 */
export interface RespHierarchy {
  next_batch?: string;
  rooms: (ChildRoomsChunk | undefined)[];
}
export interface ChildRoomsChunk {
  PublicRoomInfo: PublicRoomInfo;
  children_state: StrippedStateWithTime[];
}
export interface StrippedStateWithTime {
  StrippedState: any /* event.StrippedState */;
  origin_server_ts: any /* jsontime.UnixMilli */;
}
export interface RespAppservicePing {
  duration_ms: number /* int64 */;
}
export type RespBeeperMergeRoom = RespCreateRoom;
export interface RespBeeperSplitRoom {
  room_ids: { [key: string]: MautrixID.RoomID};
}
export interface RespTimestampToEvent {
  event_id: MautrixID.EventID;
  origin_server_ts: any /* jsontime.UnixMilli */;
}
export interface RespRoomKeysVersionCreate {
  version: any /* id.KeyBackupVersion */;
}
export interface RespRoomKeysVersion<A extends any> {
  algorithm: any /* id.KeyBackupAlgorithm */;
  auth_data: A;
  count: number /* int */;
  etag: string;
  version: any /* id.KeyBackupVersion */;
}
export interface RespRoomKeys<S extends any> {
  rooms: { [key: MautrixID.RoomID]: RespRoomKeyBackup<S>};
}
export interface RespRoomKeyBackup<S extends any> {
  sessions: { [key: any /* id.SessionID */]: RespKeyBackupData<S>};
}
export interface RespKeyBackupData<S extends any> {
  first_message_index: number /* int */;
  forwarded_count: number /* int */;
  is_verified: boolean;
  session_data: S;
}
export interface RespRoomKeysUpdate {
  count: number /* int */;
  etag: string;
}
export interface RespOpenIDToken {
  access_token: string;
  expires_in: number /* int */;
  matrix_server_name: string;
  token_type: string; // Always "Bearer"
}

//////////
// source: room.go

export type RoomStateMap = { [key: MautrixEvent.Type]: { [key: string]: MautrixEvent.Event | undefined}};
/**
 * Room represents a single Matrix room.
 */
export interface Room {
  ID: MautrixID.RoomID;
  State: RoomStateMap;
}

//////////
// source: statestore.go

/**
 * StateStore is an interface for storing basic room state information.
 */
export type StateStore = any;
export type StateStoreUpdater = any;
export interface MemoryStateStore {
  registrations: { [key: MautrixID.UserID]: boolean};
  memberships: { [key: MautrixID.RoomID]: { [key: MautrixID.UserID]: any /* event.MemberEventContent */ | undefined}};
  members_fetched: { [key: MautrixID.RoomID]: boolean};
  power_levels: { [key: MautrixID.RoomID]: MautrixEvent.PowerLevelsEventContent | undefined};
  encryption: { [key: MautrixID.RoomID]: any /* event.EncryptionEventContent */ | undefined};
}

//////////
// source: sync.go

/**
 * EventHandler handles a single event from a sync response.
 */
export type EventHandler = any;
/**
 * SyncHandler handles a whole sync response. If the return value is false, handling will be stopped completely.
 */
export type SyncHandler = any;
/**
 * Syncer is an interface that must be satisfied in order to do /sync requests on a client.
 */
export type Syncer = any;
export type ExtensibleSyncer = any;
export type DispatchableSyncer = any;
/**
 * DefaultSyncer is the default syncing implementation. You can either write your own syncer, or selectively
 * replace parts of this default syncer (e.g. the ProcessResponse method). The default syncer uses the observer
 * pattern to notify callers about incoming events. See DefaultSyncer.OnEventType for more information.
 */
export interface DefaultSyncer {
  /**
   * ParseEventContent determines whether or not event content should be parsed before passing to handlers.
   */
  ParseEventContent: boolean;
  /**
   * ParseErrorHandler is called when event.Content.ParseRaw returns an error.
   * If it returns false, the event will not be forwarded to listeners.
   */
  ParseErrorHandler: any;
  /**
   * FilterJSON is used when the client starts syncing and doesn't get an existing filter ID from SyncStore's LoadFilterID.
   */
  FilterJSON?: Filter;
}

//////////
// source: syncstore.go

/**
 * SyncStore is an interface which must be satisfied to store client data.
 * You can either write a struct which persists this data to disk, or you can use the
 * provided "MemorySyncStore" which just keeps data around in-memory which is lost on
 * restarts.
 */
export type SyncStore = any;
/**
 * Deprecated: renamed to SyncStore
 */
export type Storer = SyncStore;
/**
 * MemorySyncStore implements the Storer interface.
 * Everything is persisted in-memory as maps. It is not safe to load/save filter IDs
 * or next batch tokens on any goroutine other than the syncing goroutine: the one
 * which called Client.Sync().
 */
export interface MemorySyncStore {
  Filters: { [key: MautrixID.UserID]: string};
  NextBatch: { [key: MautrixID.UserID]: string};
}
/**
 * AccountDataStore uses account data to store the next batch token, and stores the filter ID in memory
 * (as filters can be safely recreated every startup).
 */
export interface AccountDataStore {
  FilterID: string;
  EventType: string;
}

//////////
// source: url.go

export type PrefixableURLPath = any;
export type BaseURLPath = any[];
export type ClientURLPath = any[];
export type MediaURLPath = any[];
export type SynapseAdminURLPath = any[];

//////////
// source: version.go

export const Version = "v0.23.3";

//////////
// source: versions.go

/**
 * RespVersions is the JSON response for https://spec.matrix.org/v1.2/client-server-api/#get_matrixclientversions
 */
export interface RespVersions {
  versions: SpecVersion[];
  unstable_features: { [key: string]: boolean};
}
export interface UnstableFeature {
  UnstableFlag: string;
  SpecVersion: SpecVersion;
}
export type SpecVersionFormat = number /* int */;
export const SpecVersionFormatUnknown: SpecVersionFormat = 0;
export const SpecVersionFormatR: SpecVersionFormat = 1;
export const SpecVersionFormatV: SpecVersionFormat = 2;
export interface SpecVersion {
  Format: SpecVersionFormat;
  Major: number /* int */;
  Minor: number /* int */;
  Patch: number /* int */;
  Raw: string;
}
